### LOAD PACKAGES

t0 <- Sys.time()

library(tidyverse)
library(hablar)
library(rio)
library(sustools) # devtools::install_github("ronaldoalves-ms/sustools")


### DATA IMPORT (START HERE!)

sim_crude <- import(file = "./sim_data_treated/sim_crude_data.csv", select = c("DTOBITO", "CODMUNRES", "IDADE", "CAUSABAS", "LINHAA", "LINHAB", "LINHAC", "LINHAD", "LINHAII"), colClasses = "character")

glimpse(sim_crude) # 29,689,579 deaths (1996-2021)


### DATA CLEANING

fault <- import("./ls_local_code.txt", col.names = "LOCAL_CODE")
fault <- setdiff(str_sub(sim_crude$CODMUNRES, end = 6), fault$LOCAL_CODE)

sim_clean <- 
  sim_crude %>% 
  rename("LOCAL_CODE" = "CODMUNRES", "AGE" = "IDADE", "DT_DEATH" = "DTOBITO") %>% 
  mutate(LOCAL_CODE = str_sub(LOCAL_CODE, end = 6)) %>% 
  mutate(LOCAL_CODE = ifelse(str_detect(LOCAL_CODE, "^53"), "530010", LOCAL_CODE)) %>% 
  mutate(LOCAL_CODE = case_when(LOCAL_CODE %in% fault ~ paste0(str_sub(LOCAL_CODE, end = 2), "0000"), 
                                TRUE ~ LOCAL_CODE)) %>% 
  mutate(DT_DEATH = str_pad(DT_DEATH, width = 8, side = "left", pad = 0L)) %>% 
  mutate(DAY_DEATH = as.integer(str_sub(DT_DEATH, start = 1, end = 2))) %>% 
  mutate(MONTH_DEATH = as.integer(str_sub(DT_DEATH, start = 3, end = 4))) %>% 
  mutate(YEAR_DEATH = as.integer(str_sub(DT_DEATH, start = -4))) %>% 
  mutate(AGE = case_when(str_detect(AGE, "^[0-1]") ~ 1L, # 00-06 days
                         str_detect(AGE, "^20[0-6]") ~ 1L, # 00-06 days
                         str_detect(AGE, "^20[7-9]") ~ 2L, # 07-27 days 
                         str_detect(AGE, "^21[0-9]") ~ 2L, # 07-27 days
                         str_detect(AGE, "^22[0-7]") ~ 2L, # 07-27 days
                         str_detect(AGE, "^22[8-9]") ~ 3L, # 28-364 days
                         str_detect(AGE, "^3") ~ 3L, # 28-364 days
                         str_detect(AGE, "^400") ~ 3L, # 28-364 days
                         str_detect(AGE, "^40[1-4]") ~ 4L, # 01-04 years
                         TRUE ~ 5L)) %>% 
  mutate_at(c("CAUSABAS","LINHAA","LINHAB","LINHAC","LINHAD","LINHAII"), ~str_remove_all(., "[^[:alnum:]]")) %>%
  mutate_at(c("CAUSABAS","LINHAA","LINHAB","LINHAC","LINHAD","LINHAII"), ~str_replace_na(., "")) %>%
  mutate_at(c("CAUSABAS","LINHAA","LINHAB","LINHAC","LINHAD","LINHAII"), ~str_to_upper(., "")) %>%
  #mutate(CAUSAMULT = str_c(CAUSABAS, LINHAA, LINHAB, LINHAC, LINHAD, LINHAII, sep = "")) %>% 
  select(LOCAL_CODE, DT_DEATH, DAY_DEATH, MONTH_DEATH, YEAR_DEATH, AGE, CAUSABAS)

glimpse(sim_clean)

sim_clean <- 
  sim_clean %>% 
  filter(AGE %in% c(1:3))

sim_clean <- stop_childdeath(sim_clean, sim_clean$CAUSABAS)


sim_clean <- 
  sim_clean %>% 
  mutate(FL_DEATH_AVOIDABLE = ifelse(str_detect(stop_code, "^01"), 1L, 0L),
         FL_DEATH_ILLDEFINED = ifelse(str_detect(stop_code, "^99"), 1L, 0L),
         FL_DEATH_OTHERS = ifelse(str_detect(stop_code, "^00"), 1L, 0L),
         FL_DEATH_IMMUNOPREV = ifelse(str_detect(stop_code, "^01_11"), 1L, 0L),
         FL_DEATH_CAREPREV_ALL = ifelse(str_detect(stop_code, "^01_12"), 1L, 0L),
         FL_DEATH_CAREPREV_PREG = ifelse(str_detect(stop_code, "^01_12_1"), 1L, 0L),
         FL_DEATH_CAREPREV_DELIV = ifelse(str_detect(stop_code, "^01_12_2"), 1L, 0L),
         FL_DEATH_CAREPREV_CHILD = ifelse(str_detect(stop_code, "^01_12_3"), 1L, 0L),
         FL_DEATH_DTPREV = ifelse(str_detect(stop_code, "^01_13"), 1L, 0L),
         FL_DEATH_PROMOPREV = ifelse(str_detect(stop_code, "^01_14"), 1L, 0L),
         FL_DEATH_PNEUMONIA = ifelse(stop_code == "01_13_0_056", 1L, 0L),
         FL_DEATH_IID = ifelse(stop_code == "01_14_0_072", 1L, 0L), 
         FL_DEATH_MALNUTRITION = ifelse(stop_code == "01_14_0_081", 1L, 0L),
         FL_DEATH_COVID19 = ifelse(str_detect(CAUSABAS, "B342|U07[1-2]"), 1L, 0L))


sim_clean <- 
  sim_clean %>% 
  mutate(FL1_OUT = ifelse(str_detect(LOCAL_CODE, "0000$"), 1L, 0L))


glimpse(sim_clean) # 1,261,283


### DATA SELFIE

# format(object.size(sim_clean), "Mb")
# print(summarytools::dfSummary(sim_clean, graph.col = F), method = "viewer", file = "sim_sprint_cefet_dataselfie.html")


### SAVE DATA

save(sim_clean, file = "./sim_data_treated/sim_clean_microdata_cefet.RData")

Sys.time() - t0 
